@@ -8,7 +8,6 @@
 
 #include "mainwindow.h"
 #include "krdc_debug.h"
-#include "remoteview.h"
 #include "settings.h"
 #include "config/preferencesdialog.h"
 #include "floatingtoolbar.h"
@@ -36,6 +35,7 @@
 #include <QDockWidget>
 #include <QFontMetrics>
 #include <QGroupBox>
+#include <QGuiApplication>
 #include <QHBoxLayout>
 #include <QHeaderView>
 #include <QIcon>
@@ -45,7 +45,6 @@
 #include <QMenu>
 #include <QMenuBar>
 #include <QPushButton>
-#include <QScrollArea>
 #include <QSortFilterProxyModel>
 #include <QStatusBar>
 #include <QScrollBar>
@@ -54,6 +53,7 @@
 #include <QTimer>
 #include <QToolBar>
 #include <QVBoxLayout>
+#include <QRegularExpression>
 
 MainWindow::MainWindow(QWidget *parent)
         : KXmlGuiWindow(parent),
@@ -193,27 +193,18 @@ void MainWindow::setupActions()
 
 void MainWindow::loadAllPlugins()
 {
-    const QVector<KPluginMetaData> offers = KPluginLoader::findPlugins(QStringLiteral("krdc"));
+    const QVector<KPluginMetaData> offers = KPluginMetaData::findPlugins(QStringLiteral("krdc"));
     const KConfigGroup conf = KSharedConfig::openConfig()->group(QStringLiteral("Plugins"));
 
     for (const KPluginMetaData &plugin : offers) {
-
-        KPluginInfo pluginInfo = KPluginInfo::fromMetaData(plugin);
-        pluginInfo.load(conf);
-        const bool enabled = pluginInfo.isPluginEnabled();
+        const bool enabled = plugin.isEnabled(conf);
 
         if (enabled) {
-            RemoteViewFactory *component = nullptr;
+            const auto result = KPluginFactory::instantiatePlugin<RemoteViewFactory>(plugin);
 
-            KPluginLoader loader(plugin.fileName());
-            KPluginFactory *factory = loader.factory();
-
-            if (factory) {
-                component = factory->create<RemoteViewFactory>();
-            }
-
-            if (component) {
-                const int sorting = plugin.value(QStringLiteral("X-KDE-KRDC-Sorting")).toInt();
+            if (result) {
+                RemoteViewFactory *component = result.plugin;
+                const int sorting = plugin.value(QStringLiteral("X-KDE-KRDC-Sorting"), 0);
                 m_remoteViewFactories.insert(sorting, component);
             }
         }
@@ -234,7 +225,8 @@ QUrl MainWindow::getInputUrl()
     QString userInput = m_addressInput->text();
     qCDebug(KRDC) << "input url " << userInput;
     // percent encode usernames so QUrl can parse it
-    int lastAtIndex = userInput.indexOf(QRegExp(QStringLiteral("@[^@]+$")));
+    static QRegularExpression reg(QStringLiteral("@[^@]+$"));
+    int lastAtIndex = userInput.indexOf(reg);
     if (lastAtIndex >0) {
         userInput = QString::fromLatin1(QUrl::toPercentEncoding(userInput.left(lastAtIndex))) + userInput.mid(lastAtIndex);
         qCDebug(KRDC) << "input url " << userInput;
@@ -358,11 +350,10 @@ void MainWindow::resizeTabWidget(int w, int h)
     }
 
     const QSize viewSize = QSize(w,h);
-    QDesktopWidget *desktop = QApplication::desktop();
+    QScreen *currentScreen = QGuiApplication::screenAt(geometry().center());
 
     if (Settings::fullscreenOnConnect()) {
-        int currentScreen = desktop->screenNumber(this);
-        const QSize screenSize = desktop->screenGeometry(currentScreen).size();
+        const QSize screenSize = currentScreen->availableGeometry().size();
 
         if (screenSize == viewSize) {
             qCDebug(KRDC) << "screen size equal to target view size -> switch to fullscreen mode";
@@ -375,7 +366,7 @@ void MainWindow::resizeTabWidget(int w, int h)
         QWidget* currentWidget = m_tabWidget->currentWidget();
         const QSize newWindowSize = size() - currentWidget->frameSize() + viewSize;
 
-        const QSize desktopSize = desktop->availableGeometry().size();
+        const QSize desktopSize = currentScreen->availableGeometry().size();
         qCDebug(KRDC) << "new window size: " << newWindowSize << " available space:" << desktopSize;
 
         if ((newWindowSize.width() >= desktopSize.width()) || (newWindowSize.height() >= desktopSize.height())) {
